Module swagger::add_context [−][src]
Hyper service that adds a context to an incoming request and passes it on to a wrapped service.
Structs
| AddContextMakeService | Middleware wrapper service, that should be used as the outermost layer in a
stack of hyper services. Adds a context to a plain |
| AddContextService | Middleware wrapper service, that should be used as the outermost layer in a
stack of hyper services. Adds a context to a plain |