Struct swagger::auth::AllowAllMiddleware [] [src]

pub struct AllowAllMiddleware(_);

Dummy implementation of an Iron middleware to insert authorization data, allowing all access to an endpoint with the subject "alice".

Methods

impl AllowAllMiddleware
[src]

[src]

Create a middleware that authorizes with the configured subject.