Struct swagger::auth::MakeAllowAllAuthenticator
source · [−]pub struct MakeAllowAllAuthenticator<T, RC> where
RC: RcBound,
RC::Result: Send + 'static, { /* private fields */ }Expand description
Dummy Authenticator, that blindly inserts authorization data, allowing all access to an endpoint with the specified subject.
Implementations