pub struct ApiError(pub String);
Very simple error type - just holds a description of the error. This is useful for human
diagnosis and troubleshooting, but not for applications to parse. The justification for this
is to deny applications visibility into the communication layer, forcing the application code
to act solely on the logical responses that the API provides, promoting abstraction in the
application code.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
The lower-level source of this error, if any. Read more
🔬 This is a nightly-only experimental API. (backtrace)
Returns a stack backtrace, if available, of where this error occurred. Read more
👎 Deprecated since 1.33.0:
replaced by Error::source, which can support downcasting
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.