[−][src]Struct swagger::auth::MakeAllowAllAuthenticator
Dummy Authenticator, that blindly inserts authorization data, allowing all access to an endpoint with the specified subject.
Methods
impl<T, RC> MakeAllowAllAuthenticator<T, RC> where
RC: RcBound,
RC::Result: Send + 'static, [src]
RC: RcBound,
RC::Result: Send + 'static,
pub fn new<U: Into<String>>(inner: T, subject: U) -> Self[src]
Create a middleware that authorizes with the configured subject.