Struct swagger::drop_context::DropContextMakeService [−][src]
Middleware wrapper service that drops the context from the incoming request
and passes the plain hyper::Request to the wrapped service.
This service can be used to to include services that take a plain hyper::Request
in a CompositeService wrapped in an AddContextService.
Example Usage
In the following example SwaggerService implements hyper::service::MakeService
with Request = (hyper::Request, SomeContext), and PlainService implements it
with Request = hyper::Request
ⓘ
let swagger_service_one = SwaggerService::new(); let swagger_service_two = SwaggerService::new(); let plain_service = PlainService::new(); let mut composite_new_service = CompositeMakeService::new(); composite_new_service.push(("/base/path/1", swagger_service_one)); composite_new_service.push(("/base/path/2", swagger_service_two)); composite_new_service.push(("/base/path/3", DropContextMakeService::new(plain_service)));
Implementations
impl<T, C> DropContextMakeService<T, C> where
C: Send + 'static, [src]
C: Send + 'static,